boofun.core.optimizations
===========================

.. automodule:: boofun.core.optimizations


   .. rubric:: Functions

   .. autosummary::

      BEST_INFLUENCES
      BEST_WHT
      fast_walsh_hadamard
      fast_walsh_hadamard_numba
      get_best_wht_implementation
      noise_stability_from_fourier
      vectorized_influences_from_fourier
      vectorized_influences_numba
      vectorized_total_influence_from_fourier
      vectorized_total_influence_numba
      vectorized_truth_table_to_pm

   .. rubric:: Classes

   .. autosummary::

      LazyFourierCoefficients
